@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 import LSystem2
 
-__revision__ = "$Id: demo.py 12 2005-07-10 18:43:27Z const $"
+__revision__ = "$Id: demo.py 66 2005-11-26 09:04:10Z const $"
 
 D = 128
 
-eps = LSystem2.EPS()
+eps = LSystem2.EPS(title = "LSystem Demo Fractals")
 eps.append(setlinewidth = 0.2, setlinejoin = 1)
 
 # Sierpinsky's Tetrahedron
@@ -32,4 +32,4 @@ eps.stroke(L, setrgbcolor = (0, 0, 0.7))
 L.zero = (D, D * 3**0.5)
 eps.stroke(L, setrgbcolor = (0, 0.6, 0))
 
-eps.write(file("demo.eps", "w"), title = "LSystem Demo Fractals")
+eps.write(file("demo.eps", "w"))
