@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 import LSystem2
 
-__revision__ = "$Id: sierpinsky.py 12 2005-07-10 18:43:27Z const $"
+__revision__ = "$Id: sierpinsky.py 67 2005-11-27 17:31:07Z const $"
 
 D = 128
 
@@ -10,6 +10,6 @@ L.production = (4, 0), (-1, 3**0.5), (-1, -3**0.5), (2, 0)
 L.state = (2 * D, 0), (-D, D * 3**0.5), (-D, -D * 3**0.5)
 L.depth = 6
 
-eps = LSystem2.EPS()
+eps = LSystem2.EPS(title = "Sierpinsky's Tetrahedron")
 eps.stroke(L, setlinewidth = 0.4, setrgbcolor = (0.4, 0.2, 0.6))
-eps.write(file("sierpinsky.eps", "w"), title = "Sierpinsky's Tetrahedron")
+eps.write(file("sierpinsky.eps", "w"))
